#!/usr/bin/env python
from __future__ import division

__version__ = "$Revision: 1.5 $"

import inspect
import logging
import logging.config
from path import path
import sys

LOGGINGRC_PATH = path("~/.loggingrc").expand()

if LOGGINGRC_PATH.exists():
    logging.config.fileConfig(LOGGINGRC_PATH)
else:
    logging.basicConfig()

class autolog(object):
    def __init__(self):
        self._name = self._get_name()
        self._logger = logging.getLogger(self._name)

    def __getitem__(self, name):
        if name.startswith("."):
            name = self._name + name

        return logging.getLogger(name)

    def __getattr__(self, name):
        """
        call the default logger for anything other than item
        subscripting
        """
        return getattr(self._logger, name)

    @staticmethod
    def _get_name(stacklevel=2):
        res = inspect.stack()[stacklevel][0].f_globals["__name__"]

        if res == "__main__":
            res = path(sys.argv[0]).namebase

        if not res:
            res = "root"

        return res

    def die(self, msg, *args, **kwargs):
        self.critical(msg, *args, **kwargs)
        sys.exit(1)



#!/usr/bin/env python

"""autolog: quick and easy logging setup

Autolog makes the standard Python logging module easier to set up.
"""

__version__ = "0.1.3"

# Copyright 2005,2007,2009-2010 Michael M. Hoffman <mmh1@washington.edu>

from ez_setup import use_setuptools
use_setuptools()

from setuptools import find_packages, setup

doclines = __doc__.splitlines()
name, short_description = doclines[0].split(": ")
long_description = "\n".join(doclines[2:])

url = "http://noble.gs.washington.edu/~mmh1/software/%s/" % name.lower()
download_url = "%s/%s-%s.tar.gz" % (url, name, __version__)

classifiers = ["License :: OSI Approved :: GNU General Public License (GPL)",
               "Natural Language :: English",
               "Programming Language :: Python"]

setup(name=name,
      version=__version__,
      description=short_description,
      author="Michael Hoffman",
      author_email="mmh1@uw.edu",
      url=url,
      download_url=download_url,
      license="GNU GPL v2",
      classifiers=classifiers,
      long_description = long_description,
      package_dir = {'': 'lib'},
      py_modules = ['autolog'],
      install_requires=['forked-path']
      )
